Struct ZcosmicToplevelInfoV1

pub struct ZcosmicToplevelInfoV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
list toplevels and properties thereof

The purpose of this protocol is to enable clients such as taskbars or docks to access a list of opened applications and basic properties thereof.

It thus extends ext_foreign_toplevel_v1 to provide more information and actions on foreign toplevels.

See also the Event enum for this interface.

Implementations

Source

impl ZcosmicToplevelInfoV1

pub fn stop(&self)

stop sending events

This request indicates that the client no longer wishes to receive events for new toplevels. However, the compositor may emit further toplevel_created events until the finished event is emitted.

The client must not send any more requests after this one.

Note: This request isn’t necessary for clients binding version 2 of this protocol and will be ignored.

pub fn get_cosmic_toplevel<U, D>( &self, foreign_toplevel: &ExtForeignToplevelHandleV1, qh: &QueueHandle<D>, udata: U, ) -> ZcosmicToplevelHandleV1
where U: Send + Sync + 'static, D: Dispatch<ZcosmicToplevelHandleV1, U> + 'static,

get cosmic toplevel extension object

Request a zcosmic_toplevel_handle_v1 extension object for an existing ext_foreign_toplevel_handle_v1.

All initial properties of the toplevel (states, etc.) will be sent immediately after this event via the corresponding events in zcosmic_toplevel_handle_v1.